This is an automated email from the ASF dual-hosted git repository.

stigahuang pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/impala.git

commit 026f6993edcb6e53859443928e89b3e200c68af9
Author: stiga-huang <[email protected]>
AuthorDate: Mon Jan 30 10:30:46 2023 +0800

    IMPALA-11285: Deflake timeout in test_async_load
    
    The LOAD statement in TestAsyncLoadData.test_async_load intermittently
    times out in S3 builds. The test doesn't measure the performance of the
    query execution. It just makes sure the query succeed and asserts it
    waits more than 3s (when enable_async_load_data = True). It doesn't make
    sense to fail the test if the query runs longer than 10s.
    
    This bumps the timeout from 10s to 20s.
    
    Change-Id: I1060aeb12bc4e90d676f79283ce378847dd16a3c
    Reviewed-on: http://gerrit.cloudera.org:8080/19452
    Reviewed-by: Impala Public Jenkins <[email protected]>
    Tested-by: Impala Public Jenkins <[email protected]>
---
 tests/metadata/test_load.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/tests/metadata/test_load.py b/tests/metadata/test_load.py
index 2bb13aa7e..fad5924b9 100644
--- a/tests/metadata/test_load.py
+++ b/tests/metadata/test_load.py
@@ -221,9 +221,9 @@ class TestAsyncLoadData(ImpalaTestSuite):
       exec_time = exec_end - exec_start
       exec_end_state = client.get_state(handle)
 
       # Wait for the statement to finish with a timeout of 10 seconds
       wait_start = time.time()
-      self.wait_for_state(handle, finished_state, 10, client=client)
+      self.wait_for_state(handle, finished_state, 20, client=client)
       wait_end = time.time()
       wait_time = wait_end - wait_start
       self.close_query_using_client(client, handle)
@@ -221,9 +221,9 @@ class TestAsyncLoadData(ImpalaTestSuite):
       exec_end_state = client.get_state(handle)
 
-      # Wait for the statement to finish with a timeout of 10 seconds
+      # Wait for the statement to finish with a timeout of 20 seconds
       wait_start = time.time()

Reply via email to